==> syncope-2.0.13-source-release.zip: syncope-2.0.13/core/logic/src/main/java/org/apache/syncope/core/logic/init/EntitlementLoader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.logic.init;

import java.util.Map;
import javax.sql.DataSource;
import org.apache.syncope.common.lib.types.StandardEntitlement;
import org.apache.syncope.core.provisioning.api.EntitlementsHolder;
import org.apache.syncope.core.spring.security.AuthContextUtils;
import org.apache.syncope.core.persistence.api.DomainsHolder;
import org.apache.syncope.core.persistence.api.SyncopeLoader;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class EntitlementLoader implements SyncopeLoader {

    @Autowired
    private DomainsHolder domainsHolder;

    @Autowired
    private EntitlementAccessor entitlementAccessor;

    @Override
    public Integer getPriority() {
        return 900;
    }

    @Override
    public void load() {
        EntitlementsHolder.getInstance().init(StandardEntitlement.values());

        for (Map.Entry<String, DataSource> entry : domainsHolder.getDomains().entrySet()) {
            AuthContextUtils.execWithAuthContext(entry.getKey(), new AuthContextUtils.Executable<Void>() {

                @Override
                public Void exec() {
                    entitlementAccessor.addEntitlementsForAnyTypes();
                    return null;
                }
            });
        }
    }
}

==> syncope-2.1.2-source-release.zip: syncope-2.1.2/core/logic/src/main/java/org/apache/syncope/core/logic/init/EntitlementLoader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.logic.init;

import java.util.Map;
import javax.sql.DataSource;
import org.apache.syncope.common.lib.types.StandardEntitlement;
import org.apache.syncope.core.provisioning.api.EntitlementsHolder;
import org.apache.syncope.core.spring.security.AuthContextUtils;
import org.apache.syncope.core.persistence.api.DomainsHolder;
import org.apache.syncope.core.persistence.api.SyncopeLoader;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class EntitlementLoader implements SyncopeLoader {

    @Autowired
    private DomainsHolder domainsHolder;

    @Autowired
    private EntitlementAccessor entitlementAccessor;

    @Override
    public Integer getPriority() {
        return 900;
    }

    @Override
    public void load() {
        EntitlementsHolder.getInstance().init(StandardEntitlement.values());

        for (Map.Entry<String, DataSource> entry : domainsHolder.getDomains().entrySet()) {
            AuthContextUtils.execWithAuthContext(entry.getKey(), () -> {
                entitlementAccessor.addEntitlementsForAnyTypes();
                return null;
            });
        }
    }
}
